Field

Struct Field 

pub struct Field { /* private fields */ }

Implementations

Source

impl Field

pub fn from<T>(name: T) -> Field
where T: Into<String>,

Create a field for the given name.

pub fn hide(self) -> Field

Hide field. Useful if a field should not be selected, but be used for filtering.

pub fn asc(self, order: u8) -> Field

Use this field to order records in ascending way. Give ordering priority when records are ordered by multiple fields.

pub fn desc(self, order: u8) -> Field

Use this field to order records in descending way. Give ordering priority when records are ordered by multiple fields.

pub fn eq(self, criteria: impl Into<SqlArg>) -> Field

Filter records with equal predicate.

pub fn eqn(self) -> Field

Filter records with equal null predicate.

pub fn ne(self, criteria: impl Into<SqlArg>) -> Field

Filter records with not equal predicate.

pub fn nen(self) -> Field

Filter records with not equal null predicate.

pub fn gt(self, criteria: impl Into<SqlArg>) -> Field

Filter records with greater that_ predicate.

pub fn ge(self, criteria: impl Into<SqlArg>) -> Field

Filter records with greater or equal_ predicate.

pub fn lt(self, criteria: impl Into<SqlArg>) -> Field

Filter records with lesser than_ predicate.

pub fn le(self, criteria: impl Into<SqlArg>) -> Field

Filter records with lesser or equal_ predicate.

pub fn bw(self, lower: impl Into<SqlArg>, upper: impl Into<SqlArg>) -> Field

Filter records with between predicate. This is inclusive, so x bw 3 6 is the same as x ge 3, x le 6

pub fn lk(self, criteria: impl Into<SqlArg>) -> Field

Filter records with like predicate.

pub fn ins<T, I>(self, criteria: I) -> Field
where T: Into<SqlArg>, I: IntoIterator<Item = T>,

Filter records with inside predicate.

pub fn out<T, I>(self, criteria: I) -> Field
where T: Into<SqlArg>, I: IntoIterator<Item = T>,

Filter records with outside predicate.

pub fn fnc<U, T, I>(self, name: U, args: I) -> Field
where U: Into<String>, T: Into<SqlArg>, I: IntoIterator<Item = T>,

Filter records with custom function. To provide a custom function you must implement (FieldHandler)[../table_mapper/trait.FieldHandler.html] See custom handler test for an example.

pub fn concatenate(self, concatenation: Concatenation) -> Field

pub fn into_name(self) -> String