QueryParser

Struct QueryParser 

pub struct QueryParser;
The query parser. It contains only a single static method to turn a string into a Query struct.

Implementations

Source

impl QueryParser

pub fn parse<M>(toql_query: &str) -> Result<Query<M>, ToqlError>

Method to parse a string This fails if the syntax is wrong. The original PEST error is wrapped with the ToqlError and can be used to examine to problem in detail.