pub struct RoleValidator {}Expand description
The RoleValidator validates a role expression with a set of role names.
Roles are typically assigned to a user during an authentication process.
Example
Let’s say a user authenticates and is given the roles user, subscribed and student.
For those the role expression user, teacher is invalid
while the expression user,teacher; subscribed is valid.
Implementations